summaryrefslogtreecommitdiff
path: root/fml/lib/FML/Command/User/guide.pm
diff options
context:
space:
mode:
authorfukachan <fukachan>2004-06-26 11:47:55 +0000
committerfukachan <fukachan>2004-06-26 11:47:55 +0000
commit06114f7bdcc1cf0bfd5a33a73405f607bbbfe7dd (patch)
tree88efd68768f0a4254851280c908a8642590df808 /fml/lib/FML/Command/User/guide.pm
parent8a4ad321fb933d12ba65adf4354b3fd8f4108981 (diff)
downloadfml8-06114f7bdcc1cf0bfd5a33a73405f607bbbfe7dd.tar.gz
fml8-06114f7bdcc1cf0bfd5a33a73405f607bbbfe7dd.tar.bz2
fml8-06114f7bdcc1cf0bfd5a33a73405f607bbbfe7dd.zip
overhaul: fix comments, messages and style.
Diffstat (limited to 'fml/lib/FML/Command/User/guide.pm')
-rw-r--r--fml/lib/FML/Command/User/guide.pm10
1 files changed, 5 insertions, 5 deletions
diff --git a/fml/lib/FML/Command/User/guide.pm b/fml/lib/FML/Command/User/guide.pm
index 0aa517a4..a81eeafb 100644
--- a/fml/lib/FML/Command/User/guide.pm
+++ b/fml/lib/FML/Command/User/guide.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: guide.pm,v 1.15 2004/04/23 04:10:32 fukachan Exp $
+# $FML: guide.pm,v 1.16 2004/04/23 04:15:58 fukachan Exp $
#
package FML::Command::User::guide;
@@ -18,7 +18,7 @@ use FML::Command::SendFile;
=head1 NAME
-FML::Command::User::guide - send back guide file
+FML::Command::User::guide - send back guide message.
=head1 SYNOPSIS
@@ -35,7 +35,7 @@ See C<FML::Command> for more details.
=cut
-# Descriptions: standard constructor
+# Descriptions: constructor.
# Arguments: OBJ($self)
# Side Effects: none
# Return Value: OBJ
@@ -48,14 +48,14 @@ sub new
}
-# Descriptions: need lock or not
+# Descriptions: need lock or not.
# Arguments: none
# Side Effects: none
# Return Value: NUM( 1 or 0)
sub need_lock { 0;}
# Descriptions: send guide file by FML::Command::SendFile.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: none
# Return Value: none
@@ -48,14 +48,14 @@ sub new
# Return Value: NUM( 1 or 0)
sub need_lock { 0;}
-# Descriptions: send guide file by FML::Command::SendFile.
+# Descriptions: send guide message via FML::Command::SendFile.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: none